@@ -1,5 +1,4 @@
 DATA_DIR = "/usr/share"
 LIB_DIR = "/usr/lib"
-VERSION = "2.22.3.1"
+VERSION = "2.26.2"
 PACKAGE = "deskbar-applet"
-PYTHONDIR = "/usr/lib/python2.6/site-packages"
